class PersonalConferencesController < ApplicationController
  def index
    params = OrbitHelper.params
    writing_conferences = WritingConference.where(:is_hidden=>false).sort_for_frontend.page(OrbitHelper.params[:page_no]).per(OrbitHelper.page_data_count)
    page = Page.where(:page_id => params[:page_id]).first rescue nil
    if page.custom_string_field == "table"
      fields_to_show = page.custom_array_field rescue []
      fields_to_show = [
        "authors",
        "paper_title",
        "conference_title",
        "location",
        "paper_types",
        "paper_levels"
      ] if fields_to_show.blank?
    else
      fields_to_show = [
        "year",
        "paper_title"
      ]
    end
    
    writing_conference_list = []
    writing_conferences.each do |writing_conference|
      t = []
      fields_to_show.each do |fs|
        case fs
        when "paper_title"
          if  page.custom_string_field == "table"
           t << {"value" => "<a href='#{OrbitHelper.url_to_show(writing_conference.to_param)}'>#{writing_conference.paper_title}</a>"}
          else
           t << {"value" => "<a href='#{OrbitHelper.url_to_show(writing_conference.to_param)}'>#{writing_conference.create_link}</a>"}
          end
        when "paper_levels"
          t << {"value" => ( !writing_conference.conference_paper_levels.blank? ? "(#{writing_conference.conference_paper_levels.collect{|x| x.title}.join(', ')})" : nil)} 
        when "paper_types"
          t << {"value" => ( !writing_conference.conference_paper_levels.blank? ? "(#{writing_conference.conference_paper_levels.collect{|x| x.title}.join(', ')})" : nil)} 
        when "publication_date"
          t << {"value" => (writing_conference.send(fs).strftime("%Y/%m") rescue "")}
        when "author_type"
          t << {"value" => (writing_conference.conference_author_types.collect{|cat| cat.title}.join(", ") rescue "")}
        when "period"
          t << {"value" => writing_conference.duration}
        else
          t << {"value" => writing_conference.send(fs)}
        end
      end
      writing_conference_list << {"cps" => t}
    end

    headers = []
    fields_to_show.each do |fs|
      col = 2
      col = 3 if fs == "paper_title"
      headers << {
        "head-title" => t("personal_conference.#{fs}"),
        "col" => col
      }
    end

    {
      "writing_conferences" => writing_conference_list,
      "extras" => { "widget-title" => t("module_name.personal_conference") },
      "headers" => headers,
      "total_pages" => writing_conferences.total_pages
    }
  end

  def show
    params = OrbitHelper.params
    plugin = WritingConference.where(:is_hidden=>false).find_by(uid: params[:uid])

    fields_to_show = [
      "year", 
      "authors", 
      "paper_title", 
      "conference_title", 
      "location", 
      "period_start_date", 
      "period_end_date", 
      "period",
      "paper_type",
      "paper_level",
      "sponsor", 
      "author_type",
      "number_of_authors",
      "abstract",
      "url", 
      "file", 
      "publication_date",
      "isbn", 
      "isi_number" ,
      "language" 
    ]
    
    {"plugin_datas"=>plugin.get_plugin_data(fields_to_show)}
  end

  def get_fields_for_index
    @page = Page.find(params[:page_id]) rescue nil
    @fields_to_show = [
     "year", 
      "authors", 
      "paper_title", 
      "conference_title", 
      "location", 
      "period_start_date", 
      "period_end_date", 
      "period",
      "paper_type",
      "paper_level",
      "sponsor", 
      "author_type",
      "number_of_authors",
      "abstract",
      "url", 
      "publication_date",
      "isbn", 
      "isi_number" ,
      "language" 
    ]
    @fields_to_show = @fields_to_show.map{|fs| [t("personal_conference.#{fs}"), fs]}
    @default_fields_to_show = [
      "authors",
      "paper_title",
      "conference_title",
      "location",
      "paper_types",
      "paper_levels"
    ]
    render :layout => false
  end

  def save_index_fields
    page = Page.find(params[:page_id]) rescue nil
    page.custom_array_field = params[:keys]
    page.save
    render :json => {"success" => true}.to_json
  end
end